.. _encryption_setting:

Encryption Settings
===================

.. autoclass:: b2sdk.v2.EncryptionKey()
   :no-members:
   :special-members: __init__

.. autoclass:: b2sdk.v2.UNKNOWN_KEY_ID
   :no-members:

.. autoclass:: b2sdk.v2.EncryptionSetting()
   :no-members:
   :special-members: __init__, as_dict


.. autoattribute:: b2sdk.v2.SSE_NONE

    Commonly used "no encryption" setting


.. autoattribute:: b2sdk.v2.SSE_B2_AES

    Commonly used SSE-B2 setting
